command

package
v0.0.0-...-4c68e2a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 21, 2015 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MD5Command

type MD5Command struct {
	UI cli.Ui
}

MD5Command is a Command implementation that says hello world

func (*MD5Command) Help

func (c *MD5Command) Help() string

Help prints the help text for the run sub-command.

func (*MD5Command) Run

func (c *MD5Command) Run(args []string) int

Run runs the square command; the args are a variadic list of strings that represent ints to square

func (*MD5Command) Synopsis

func (c *MD5Command) Synopsis() string

Synopsis provides a precis of the hello command.

type SHA256Command

type SHA256Command struct {
	UI cli.Ui
}

SHA256Command is a Command implementation that says hello world

func (*SHA256Command) Help

func (c *SHA256Command) Help() string

Help prints the help text for the run sub-command.

func (*SHA256Command) Run

func (c *SHA256Command) Run(args []string) int

Run runs the square command; the args are a variadic list of strings that represent ints to square

func (*SHA256Command) Synopsis

func (c *SHA256Command) Synopsis() string

Synopsis provides a precis of the hello command.

type SquareCommand

type SquareCommand struct {
	UI cli.Ui
}

SqueareCommand is a Command implementation that says hello world

func (*SquareCommand) Help

func (c *SquareCommand) Help() string

Help prints the help text for the run sub-command.

func (*SquareCommand) Run

func (c *SquareCommand) Run(args []string) int

Run runs the square command; the args are a variadic list of strings that represent ints to square

func (*SquareCommand) Synopsis

func (c *SquareCommand) Synopsis() string

Synopsis provides a precis of the hello command.

type VersionCommand

type VersionCommand struct {
	Name              string
	Revision          string
	Version           string
	VersionPrerelease string
	UI                cli.Ui
}

VersionCommand is a Command implementation that prints the version.

func (*VersionCommand) Help

func (c *VersionCommand) Help() string

Help prints the Help text for the version sub-command

func (*VersionCommand) Run

func (c *VersionCommand) Run(_ []string) int

Run runs the version sub-command.

func (*VersionCommand) Synopsis

func (c *VersionCommand) Synopsis() string

Synopsis provides a precis of the version sub-command.

Jump to